@@ -88,15 +88,28 @@
  * ######################################################################
  */
 
-#if BUILD_DLL /* DLL kompilieren */
-# define DLL_EXPORT __declspec (dllexport) __stdcall 
-# define DLL_EXPORT_V __declspec (dllexport)
-#elif USE_DLL /* DLL in einem anderen Programm benutzen */
-# define DLL_EXPORT __declspec (dllimport) __stdcall 
-# define DLL_EXPORT_V __declspec (dllimport)
-#else /* kein DLL-Krempel erforderlich */
-# define DLL_EXPORT
-# define DLL_EXPORT_V
+#if USE_CDECL
+#  if BUILD_DLL /* DLL kompilieren */
+#    define DLL_EXPORT __declspec (dllexport)
+#    define DLL_EXPORT_V __declspec (dllexport)
+#  elif USE_DLL /* DLL in einem anderen Programm benutzen */
+#    define DLL_EXPORT __declspec (dllimport)
+#    define DLL_EXPORT_V __declspec (dllimport)
+#  else /* kein DLL-Krempel erforderlich */
+#    define DLL_EXPORT
+#    define DLL_EXPORT_V
+#  endif
+#else
+#   if BUILD_DLL /* DLL kompilieren */
+#    define DLL_EXPORT __declspec (dllexport) __stdcall 
+#    define DLL_EXPORT_V __declspec (dllexport)
+#  elif USE_DLL /* DLL in einem anderen Programm benutzen */
+#    define DLL_EXPORT __declspec (dllimport) __stdcall 
+#    define DLL_EXPORT_V __declspec (dllimport)
+#  else /* kein DLL-Krempel erforderlich */
+#    define DLL_EXPORT
+#    define DLL_EXPORT_V
+#  endif
 #endif
 
 /*
